@@ -54,7 +54,7 @@
 #include "server.h"
 #include "tree.h"
 #include "outbound.h"
-
+#include "chanopt.h"
 
 #ifdef USE_DEBUG
 extern int current_mem_usage;
@@ -2386,9 +2386,13 @@ cmd_lastlog (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	if (*word_eol[2])
 	{
 		if (!strcmp (word[2], "-r"))
+		{
 			lastlog (sess, word_eol[3], TRUE);
+		}
 		else
+		{
 			lastlog (sess, word_eol[2], FALSE);
+		}
 		return TRUE;
 	}
 
@@ -3598,7 +3602,7 @@ const struct commands xc_cmds[] = {
 	{"LAGCHECK", cmd_lagcheck, 0, 0, 1,
 	 N_("LAGCHECK, forces a new lag check")},
 	{"LASTLOG", cmd_lastlog, 0, 0, 1,
-	 N_("LASTLOG <string>, searches for a string in the buffer")},
+	 N_("LASTLOG [-r] <string>, searches for a string in the buffer")},
 	{"LIST", cmd_list, 1, 0, 1, 0},
 	{"LOAD", cmd_load, 0, 0, 1, N_("LOAD [-e] <file>, loads a plugin or script")},
 
