@@ -25,7 +25,9 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 
-#ifndef WIN32
+#ifdef WIN32
+#include <io.h>
+#else
 #include <unistd.h>
 #include <sys/mman.h>
 #endif
@@ -338,9 +340,15 @@ scrollback_load (session *sess)
 			text = strchr (buf + 3, ' ');
 			if (text)
 			{
-				text = strip_color (text + 1, -1, STRIP_COLOR);
+				if (prefs.text_replay_strip_color)
+				{
+					text = strip_color (text + 1, -1, STRIP_COLOR);
+				}
 				fe_print_text (sess, text, stamp);
-				g_free (text);
+				if (prefs.text_replay_strip_color)
+				{
+					g_free (text);
+				}
 			}
 			lines++;
 		}
@@ -373,15 +381,24 @@ scrollback_load (session *sess)
 			text = strchr (buf + 3, ' ');
 			if (text)
 			{
-				text = strip_color (text + 1, -1, STRIP_COLOR);
+				if (prefs.text_replay_strip_color)
+				{
+					text = strip_color (text + 1, -1, STRIP_COLOR);
+				}
 				cleaned_text = text_replace_non_bmp (text, -1, &cleaned_len);
 				if (cleaned_text != NULL)
 				{
-					g_free (text);
+					if (prefs.text_replay_strip_color)
+					{
+						g_free (text);
+					}
 					text = cleaned_text;
 				}
 				fe_print_text (sess, text, stamp);
-				g_free (text);
+				if (prefs.text_replay_strip_color)
+				{
+					g_free (text);
+				}
 			}
 			lines++;
 		}
@@ -2263,6 +2280,10 @@ sound_play (const char *file, gboolean quiet)
 	char wavfile[512];
 	char *file_fs;
 	char *cmd;
+#if 0
+	LPSTR lpRes;
+	HANDLE hResInfo, hRes;
+#endif
 
 	/* the pevents GUI editor triggers this after removing a soundfile */
 	if (!file[0])
@@ -2297,6 +2318,27 @@ sound_play (const char *file, gboolean quiet)
 		if (cmd == NULL || strcmp (cmd, "esdplay") == 0)
 		{
 			PlaySound (file_fs, NULL, SND_NODEFAULT|SND_FILENAME|SND_ASYNC);
+#if 0			/* this would require the wav file to be added to the executable as resource */
+			hResInfo = FindResource (NULL, file_fs, "WAVE");
+			if (hResInfo != NULL)
+			{
+				/* load the WAVE resource */
+				hRes = LoadResource (NULL, hResInfo);
+				if (hRes != NULL)
+				{
+					/* lock the WAVE resource and play it */
+					lpRes = LockResource(hRes);
+					if (lpRes != NULL)
+					{
+						sndPlaySound (lpRes, SND_MEMORY | SND_NODEFAULT | SND_FILENAME | SND_ASYNC);
+						UnlockResource (hRes);
+					}
+
+					/* free the WAVE resource */
+					FreeResource (hRes);
+				}
+			}
+#endif
 		} else
 #endif
 		{
